Class: Aws::Textract::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Textract::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-textract/client.rb,
sig/client.rbs
Overview
An API client for Textract. To construct a client, you need to configure a :region and :credentials.
client = Aws::Textract::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AnalyzeDocumentResponseSuccess, _AnalyzeExpenseResponseSuccess, _AnalyzeIDResponseSuccess, _CreateAdapterResponseSuccess, _CreateAdapterVersionResponseSuccess, _DeleteAdapterResponseSuccess, _DeleteAdapterVersionResponseSuccess, _DetectDocumentTextResponseSuccess, _GetAdapterResponseSuccess, _GetAdapterVersionResponseSuccess, _GetDocumentAnalysisResponseSuccess, _GetDocumentTextDetectionResponseSuccess, _GetExpenseAnalysisResponseSuccess, _GetLendingAnalysisResponseSuccess, _GetLendingAnalysisSummaryResponseSuccess, _ListAdapterVersionsResponseSuccess, _ListAdaptersResponseSuccess, _ListTagsForResourceResponseSuccess, _StartDocumentAnalysisResponseSuccess, _StartDocumentTextDetectionResponseSuccess, _StartExpenseAnalysisResponseSuccess, _StartLendingAnalysisResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAdapterResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#analyze_document(params = {}) ⇒ Types::AnalyzeDocumentResponse
Analyzes an input document for relationships between detected items.
-
#analyze_expense(params = {}) ⇒ Types::AnalyzeExpenseResponse
AnalyzeExpensesynchronously analyzes an input document for financially related relationships between text. -
#analyze_id(params = {}) ⇒ Types::AnalyzeIDResponse
Analyzes identity documents for relevant information.
-
#create_adapter(params = {}) ⇒ Types::CreateAdapterResponse
Creates an adapter, which can be fine-tuned for enhanced performance on user provided documents.
-
#create_adapter_version(params = {}) ⇒ Types::CreateAdapterVersionResponse
Creates a new version of an adapter.
-
#delete_adapter(params = {}) ⇒ Struct
Deletes an Amazon Textract adapter.
-
#delete_adapter_version(params = {}) ⇒ Struct
Deletes an Amazon Textract adapter version.
-
#detect_document_text(params = {}) ⇒ Types::DetectDocumentTextResponse
Detects text in the input document.
-
#get_adapter(params = {}) ⇒ Types::GetAdapterResponse
Gets configuration information for an adapter specified by an AdapterId, returning information on AdapterName, Description, CreationTime, AutoUpdate status, and FeatureTypes.
-
#get_adapter_version(params = {}) ⇒ Types::GetAdapterVersionResponse
Gets configuration information for the specified adapter version, including: AdapterId, AdapterVersion, FeatureTypes, Status, StatusMessage, DatasetConfig, KMSKeyId, OutputConfig, Tags and EvaluationMetrics.
-
#get_document_analysis(params = {}) ⇒ Types::GetDocumentAnalysisResponse
Gets the results for an Amazon Textract asynchronous operation that analyzes text in a document.
-
#get_document_text_detection(params = {}) ⇒ Types::GetDocumentTextDetectionResponse
Gets the results for an Amazon Textract asynchronous operation that detects text in a document.
-
#get_expense_analysis(params = {}) ⇒ Types::GetExpenseAnalysisResponse
Gets the results for an Amazon Textract asynchronous operation that analyzes invoices and receipts.
-
#get_lending_analysis(params = {}) ⇒ Types::GetLendingAnalysisResponse
Gets the results for an Amazon Textract asynchronous operation that analyzes text in a lending document.
-
#get_lending_analysis_summary(params = {}) ⇒ Types::GetLendingAnalysisSummaryResponse
Gets summarized results for the
StartLendingAnalysisoperation, which analyzes text in a lending document. -
#list_adapter_versions(params = {}) ⇒ Types::ListAdapterVersionsResponse
List all version of an adapter that meet the specified filtration criteria.
-
#list_adapters(params = {}) ⇒ Types::ListAdaptersResponse
Lists all adapters that match the specified filtration criteria.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags for an Amazon Textract resource.
-
#start_document_analysis(params = {}) ⇒ Types::StartDocumentAnalysisResponse
Starts the asynchronous analysis of an input document for relationships between detected items such as key-value pairs, tables, and selection elements.
-
#start_document_text_detection(params = {}) ⇒ Types::StartDocumentTextDetectionResponse
Starts the asynchronous detection of text in a document.
-
#start_expense_analysis(params = {}) ⇒ Types::StartExpenseAnalysisResponse
Starts the asynchronous analysis of invoices or receipts for data like contact information, items purchased, and vendor names.
-
#start_lending_analysis(params = {}) ⇒ Types::StartLendingAnalysisResponse
Starts the classification and analysis of an input document.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes any tags with the specified keys from the specified resource.
-
#update_adapter(params = {}) ⇒ Types::UpdateAdapterResponse
Update the configuration for an adapter.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-textract/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2873 2874 2875 |
# File 'lib/aws-sdk-textract/client.rb', line 2873 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2876 2877 2878 |
# File 'lib/aws-sdk-textract/client.rb', line 2876 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#analyze_document(params = {}) ⇒ Types::AnalyzeDocumentResponse
Analyzes an input document for relationships between detected items.
The types of information returned are as follows:
-
Form data (key-value pairs). The related information is returned in two Block objects, each of type
KEY_VALUE_SET: a KEYBlockobject and a VALUEBlockobject. For example, Name: Ana Silva Carolina contains a key and value. Name: is the key. Ana Silva Carolina is the value. -
Table and table cell data. A TABLE
Blockobject contains information about a detected table. A CELLBlockobject is returned for each cell in a table. -
Lines and words of text. A LINE
Blockobject contains one or more WORDBlockobjects. All lines and words that are detected in the document are returned (including text that doesn't have a relationship with the value ofFeatureTypes). -
Signatures. A SIGNATURE
Blockobject contains the location information of a signature in a document. If used in conjunction with forms or tables, a signature can be given a Key-Value pairing or be detected in the cell of a table. -
Query. A QUERY Block object contains the query text, alias and link to the associated Query results block object.
-
Query Result. A QUERY_RESULT Block object contains the answer to the query and an ID that connects it to the query asked. This Block also contains a confidence score.
Selection elements such as check boxes and option buttons (radio
buttons) can be detected in form data and in tables. A
SELECTION_ELEMENT Block object contains information about a
selection element, including the selection status.
You can choose which type of analysis to perform by specifying the
FeatureTypes list.
The output is returned in a list of Block objects.
AnalyzeDocument is a synchronous operation. To analyze documents
asynchronously, use StartDocumentAnalysis.
For more information, see Document Text Analysis.
90 |
# File 'sig/client.rbs', line 90
def analyze_document: (
|
#analyze_expense(params = {}) ⇒ Types::AnalyzeExpenseResponse
AnalyzeExpense synchronously analyzes an input document for
financially related relationships between text.
Information is returned as ExpenseDocuments and seperated as
follows:
-
LineItemGroups- A data set containingLineItemswhich store information about the lines of text, such as an item purchased and its price on a receipt. -
SummaryFields- Contains all other information a receipt, such as header information or the vendors name.
127 |
# File 'sig/client.rbs', line 127
def analyze_expense: (
|
#analyze_id(params = {}) ⇒ Types::AnalyzeIDResponse
Analyzes identity documents for relevant information. This information
is extracted and returned as IdentityDocumentFields, which records
both the normalized field and value of the extracted text. Unlike
other Amazon Textract operations, AnalyzeID doesn't return any
Geometry data.
139 |
# File 'sig/client.rbs', line 139
def analyze_id: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 |
# File 'lib/aws-sdk-textract/client.rb', line 2846 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Textract') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-textract' context[:gem_version] = '1.95.0' Seahorse::Client::Request.new(handlers, context) end |
#create_adapter(params = {}) ⇒ Types::CreateAdapterResponse
Creates an adapter, which can be fine-tuned for enhanced performance
on user provided documents. Takes an AdapterName and FeatureType.
Currently the only supported feature type is QUERIES. You can also
provide a Description, Tags, and a ClientRequestToken. You can choose
whether or not the adapter should be AutoUpdated with the AutoUpdate
argument. By default, AutoUpdate is set to DISABLED.
151 |
# File 'sig/client.rbs', line 151
def create_adapter: (
|
#create_adapter_version(params = {}) ⇒ Types::CreateAdapterVersionResponse
Creates a new version of an adapter. Operates on a provided AdapterId and a specified dataset provided via the DatasetConfig argument. Requires that you specify an Amazon S3 bucket with the OutputConfig argument. You can provide an optional KMSKeyId, an optional ClientRequestToken, and optional tags.
167 |
# File 'sig/client.rbs', line 167
def create_adapter_version: (
|
#delete_adapter(params = {}) ⇒ Struct
Deletes an Amazon Textract adapter. Takes an AdapterId and deletes the adapter specified by the ID.
190 |
# File 'sig/client.rbs', line 190
def delete_adapter: (
|
#delete_adapter_version(params = {}) ⇒ Struct
Deletes an Amazon Textract adapter version. Requires that you specify both an AdapterId and a AdapterVersion. Deletes the adapter version specified by the AdapterId and the AdapterVersion.
199 |
# File 'sig/client.rbs', line 199
def delete_adapter_version: (
|
#detect_document_text(params = {}) ⇒ Types::DetectDocumentTextResponse
Detects text in the input document. Amazon Textract can detect lines
of text and the words that make up a line of text. The input document
must be in one of the following image formats: JPEG, PNG, PDF, or
TIFF. DetectDocumentText returns the detected text in an array of
Block objects.
Each document page has as an associated Block of type PAGE. Each
PAGE Block object is the parent of LINE Block objects that
represent the lines of detected text on a page. A LINE Block object
is a parent for each word that makes up the line. Words are
represented by Block objects of type WORD.
DetectDocumentText is a synchronous operation. To analyze documents
asynchronously, use StartDocumentTextDetection.
For more information, see Document Text Detection.
212 |
# File 'sig/client.rbs', line 212
def detect_document_text: (
|
#get_adapter(params = {}) ⇒ Types::GetAdapterResponse
Gets configuration information for an adapter specified by an AdapterId, returning information on AdapterName, Description, CreationTime, AutoUpdate status, and FeatureTypes.
228 |
# File 'sig/client.rbs', line 228
def get_adapter: (
|
#get_adapter_version(params = {}) ⇒ Types::GetAdapterVersionResponse
Gets configuration information for the specified adapter version, including: AdapterId, AdapterVersion, FeatureTypes, Status, StatusMessage, DatasetConfig, KMSKeyId, OutputConfig, Tags and EvaluationMetrics.
248 |
# File 'sig/client.rbs', line 248
def get_adapter_version: (
|
#get_document_analysis(params = {}) ⇒ Types::GetDocumentAnalysisResponse
Gets the results for an Amazon Textract asynchronous operation that analyzes text in a document.
You start asynchronous text analysis by calling StartDocumentAnalysis,
which returns a job identifier (JobId). When the text analysis
operation finishes, Amazon Textract publishes a completion status to
the Amazon Simple Notification Service (Amazon SNS) topic that's
registered in the initial call to StartDocumentAnalysis. To get the
results of the text-detection operation, first check that the status
value published to the Amazon SNS topic is SUCCEEDED. If so, call
GetDocumentAnalysis, and pass the job identifier (JobId) from the
initial call to StartDocumentAnalysis.
GetDocumentAnalysis returns an array of Block objects. The following
types of information are returned:
-
Form data (key-value pairs). The related information is returned in two Block objects, each of type
KEY_VALUE_SET: a KEYBlockobject and a VALUEBlockobject. For example, Name: Ana Silva Carolina contains a key and value. Name: is the key. Ana Silva Carolina is the value. -
Table and table cell data. A TABLE
Blockobject contains information about a detected table. A CELLBlockobject is returned for each cell in a table. -
Lines and words of text. A LINE
Blockobject contains one or more WORDBlockobjects. All lines and words that are detected in the document are returned (including text that doesn't have a relationship with the value of theStartDocumentAnalysisFeatureTypesinput parameter). -
Query. A QUERY Block object contains the query text, alias and link to the associated Query results block object.
-
Query Results. A QUERY_RESULT Block object contains the answer to the query and an ID that connects it to the query asked. This Block also contains a confidence score.
INVALID_REQUEST_PARAMETERS output. This indicates that either the
per page query limit has been exceeded or that the operation is trying
to query a page in the document which doesn’t exist.
Selection elements such as check boxes and option buttons (radio
buttons) can be detected in form data and in tables. A
SELECTION_ELEMENT Block object contains information about a
selection element, including the selection status.
Use the MaxResults parameter to limit the number of blocks that are
returned. If there are more results than specified in MaxResults,
the value of NextToken in the operation response contains a
pagination token for getting the next set of results. To get the next
page of results, call GetDocumentAnalysis, and populate the
NextToken request parameter with the token value that's returned
from the previous call to GetDocumentAnalysis.
For more information, see Document Text Analysis.
265 |
# File 'sig/client.rbs', line 265
def get_document_analysis: (
|
#get_document_text_detection(params = {}) ⇒ Types::GetDocumentTextDetectionResponse
Gets the results for an Amazon Textract asynchronous operation that detects text in a document. Amazon Textract can detect lines of text and the words that make up a line of text.
You start asynchronous text detection by calling
StartDocumentTextDetection, which returns a job identifier (JobId).
When the text detection operation finishes, Amazon Textract publishes
a completion status to the Amazon Simple Notification Service (Amazon
SNS) topic that's registered in the initial call to
StartDocumentTextDetection. To get the results of the text-detection
operation, first check that the status value published to the Amazon
SNS topic is SUCCEEDED. If so, call GetDocumentTextDetection, and
pass the job identifier (JobId) from the initial call to
StartDocumentTextDetection.
GetDocumentTextDetection returns an array of Block objects.
Each document page has as an associated Block of type PAGE. Each
PAGE Block object is the parent of LINE Block objects that
represent the lines of detected text on a page. A LINE Block object
is a parent for each word that makes up the line. Words are
represented by Block objects of type WORD.
Use the MaxResults parameter to limit the number of blocks that are
returned. If there are more results than specified in MaxResults,
the value of NextToken in the operation response contains a
pagination token for getting the next set of results. To get the next
page of results, call GetDocumentTextDetection, and populate the
NextToken request parameter with the token value that's returned
from the previous call to GetDocumentTextDetection.
For more information, see Document Text Detection.
283 |
# File 'sig/client.rbs', line 283
def get_document_text_detection: (
|
#get_expense_analysis(params = {}) ⇒ Types::GetExpenseAnalysisResponse
Gets the results for an Amazon Textract asynchronous operation that analyzes invoices and receipts. Amazon Textract finds contact information, items purchased, and vendor name, from input invoices and receipts.
You start asynchronous invoice/receipt analysis by calling
StartExpenseAnalysis, which returns a job identifier (JobId). Upon
completion of the invoice/receipt analysis, Amazon Textract publishes
the completion status to the Amazon Simple Notification Service
(Amazon SNS) topic. This topic must be registered in the initial call
to StartExpenseAnalysis. To get the results of the invoice/receipt
analysis operation, first ensure that the status value published to
the Amazon SNS topic is SUCCEEDED. If so, call GetExpenseAnalysis,
and pass the job identifier (JobId) from the initial call to
StartExpenseAnalysis.
Use the MaxResults parameter to limit the number of blocks that are
returned. If there are more results than specified in MaxResults,
the value of NextToken in the operation response contains a
pagination token for getting the next set of results. To get the next
page of results, call GetExpenseAnalysis, and populate the
NextToken request parameter with the token value that's returned
from the previous call to GetExpenseAnalysis.
For more information, see Analyzing Invoices and Receipts.
301 |
# File 'sig/client.rbs', line 301
def get_expense_analysis: (
|
#get_lending_analysis(params = {}) ⇒ Types::GetLendingAnalysisResponse
Gets the results for an Amazon Textract asynchronous operation that analyzes text in a lending document.
You start asynchronous text analysis by calling
StartLendingAnalysis, which returns a job identifier (JobId). When
the text analysis operation finishes, Amazon Textract publishes a
completion status to the Amazon Simple Notification Service (Amazon
SNS) topic that's registered in the initial call to
StartLendingAnalysis.
To get the results of the text analysis operation, first check that
the status value published to the Amazon SNS topic is SUCCEEDED. If
so, call GetLendingAnalysis, and pass the job identifier (JobId)
from the initial call to StartLendingAnalysis.
319 |
# File 'sig/client.rbs', line 319
def get_lending_analysis: (
|
#get_lending_analysis_summary(params = {}) ⇒ Types::GetLendingAnalysisSummaryResponse
Gets summarized results for the StartLendingAnalysis operation,
which analyzes text in a lending document. The returned summary
consists of information about documents grouped together by a common
document type. Information like detected signatures, page numbers, and
split documents is returned with respect to the type of grouped
document.
You start asynchronous text analysis by calling
StartLendingAnalysis, which returns a job identifier (JobId). When
the text analysis operation finishes, Amazon Textract publishes a
completion status to the Amazon Simple Notification Service (Amazon
SNS) topic that's registered in the initial call to
StartLendingAnalysis.
To get the results of the text analysis operation, first check that
the status value published to the Amazon SNS topic is SUCCEEDED. If
so, call GetLendingAnalysisSummary, and pass the job identifier
(JobId) from the initial call to StartLendingAnalysis.
336 |
# File 'sig/client.rbs', line 336
def get_lending_analysis_summary: (
|
#list_adapter_versions(params = {}) ⇒ Types::ListAdapterVersionsResponse
List all version of an adapter that meet the specified filtration criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
347 |
# File 'sig/client.rbs', line 347
def list_adapter_versions: (
|
#list_adapters(params = {}) ⇒ Types::ListAdaptersResponse
Lists all adapters that match the specified filtration criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
362 |
# File 'sig/client.rbs', line 362
def list_adapters: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags for an Amazon Textract resource.
375 |
# File 'sig/client.rbs', line 375
def list_tags_for_resource: (
|
#start_document_analysis(params = {}) ⇒ Types::StartDocumentAnalysisResponse
Starts the asynchronous analysis of an input document for relationships between detected items such as key-value pairs, tables, and selection elements.
StartDocumentAnalysis can analyze text in documents that are in
JPEG, PNG, TIFF, and PDF format. The documents are stored in an Amazon
S3 bucket. Use DocumentLocation to specify the bucket name and file
name of the document.
StartDocumentAnalysis returns a job identifier (JobId) that you
use to get the results of the operation. When text analysis is
finished, Amazon Textract publishes a completion status to the Amazon
Simple Notification Service (Amazon SNS) topic that you specify in
NotificationChannel. To get the results of the text analysis
operation, first check that the status value published to the Amazon
SNS topic is SUCCEEDED. If so, call GetDocumentAnalysis, and pass
the job identifier (JobId) from the initial call to
StartDocumentAnalysis.
For more information, see Document Text Analysis.
385 |
# File 'sig/client.rbs', line 385
def start_document_analysis: (
|
#start_document_text_detection(params = {}) ⇒ Types::StartDocumentTextDetectionResponse
Starts the asynchronous detection of text in a document. Amazon Textract can detect lines of text and the words that make up a line of text.
StartDocumentTextDetection can analyze text in documents that are in
JPEG, PNG, TIFF, and PDF format. The documents are stored in an Amazon
S3 bucket. Use DocumentLocation to specify the bucket name and file
name of the document.
StartDocumentTextDetection returns a job identifier (JobId) that
you use to get the results of the operation. When text detection is
finished, Amazon Textract publishes a completion status to the Amazon
Simple Notification Service (Amazon SNS) topic that you specify in
NotificationChannel. To get the results of the text detection
operation, first check that the status value published to the Amazon
SNS topic is SUCCEEDED. If so, call GetDocumentTextDetection, and
pass the job identifier (JobId) from the initial call to
StartDocumentTextDetection.
For more information, see Document Text Detection.
431 |
# File 'sig/client.rbs', line 431
def start_document_text_detection: (
|
#start_expense_analysis(params = {}) ⇒ Types::StartExpenseAnalysisResponse
Starts the asynchronous analysis of invoices or receipts for data like contact information, items purchased, and vendor names.
StartExpenseAnalysis can analyze text in documents that are in JPEG,
PNG, and PDF format. The documents must be stored in an Amazon S3
bucket. Use the DocumentLocation parameter to specify the name of your
S3 bucket and the name of the document in that bucket.
StartExpenseAnalysis returns a job identifier (JobId) that you
will provide to GetExpenseAnalysis to retrieve the results of the
operation. When the analysis of the input invoices/receipts is
finished, Amazon Textract publishes a completion status to the Amazon
Simple Notification Service (Amazon SNS) topic that you provide to the
NotificationChannel. To obtain the results of the invoice and
receipt analysis operation, ensure that the status value published to
the Amazon SNS topic is SUCCEEDED. If so, call GetExpenseAnalysis,
and pass the job identifier (JobId) that was returned by your call
to StartExpenseAnalysis.
For more information, see Analyzing Invoices and Receipts.
458 |
# File 'sig/client.rbs', line 458
def start_expense_analysis: (
|
#start_lending_analysis(params = {}) ⇒ Types::StartLendingAnalysisResponse
Starts the classification and analysis of an input document.
StartLendingAnalysis initiates the classification and analysis of a
packet of lending documents. StartLendingAnalysis operates on a
document file located in an Amazon S3 bucket.
StartLendingAnalysis can analyze text in documents that are in one
of the following formats: JPEG, PNG, TIFF, PDF. Use DocumentLocation
to specify the bucket name and the file name of the document.
StartLendingAnalysis returns a job identifier (JobId) that you use
to get the results of the operation. When the text analysis is
finished, Amazon Textract publishes a completion status to the Amazon
Simple Notification Service (Amazon SNS) topic that you specify in
NotificationChannel. To get the results of the text analysis
operation, first check that the status value published to the Amazon
SNS topic is SUCCEEDED. If the status is SUCCEEDED you can call either
GetLendingAnalysis or GetLendingAnalysisSummary and provide the
JobId to obtain the results of the analysis.
If using OutputConfig to specify an Amazon S3 bucket, the output
will be contained within the specified prefix in a directory labeled
with the job-id. In the directory there are 3 sub-directories:
-
detailedResponse (contains the GetLendingAnalysis response)
-
summaryResponse (for the GetLendingAnalysisSummary response)
-
splitDocuments (documents split across logical boundaries)
485 |
# File 'sig/client.rbs', line 485
def start_lending_analysis: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
511 |
# File 'sig/client.rbs', line 511
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes any tags with the specified keys from the specified resource.
521 |
# File 'sig/client.rbs', line 521
def untag_resource: (
|
#update_adapter(params = {}) ⇒ Types::UpdateAdapterResponse
Update the configuration for an adapter. FeatureTypes configurations cannot be updated. At least one new parameter must be specified as an argument.
537 |
# File 'sig/client.rbs', line 537
def update_adapter: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2866 2867 2868 |
# File 'lib/aws-sdk-textract/client.rb', line 2866 def waiter_names [] end |