Class: Aws::Textract::Types::AnalyzeDocumentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#adapters_configTypes::AdaptersConfig

Specifies the adapter to be used when analyzing a document.



249
250
251
252
253
254
255
256
257
# File 'lib/aws-sdk-textract/types.rb', line 249

class AnalyzeDocumentRequest < Struct.new(
  :document,
  :feature_types,
  :human_loop_config,
  :queries_config,
  :adapters_config)
  SENSITIVE = []
  include Aws::Structure
end

#documentTypes::Document

The input document as base64-encoded bytes or an Amazon S3 object. If you use the AWS CLI to call Amazon Textract operations, you can't pass image bytes. The document must be an image in JPEG, PNG, PDF, or TIFF format.

If you're using an AWS SDK to call Amazon Textract, you might not need to base64-encode image bytes that are passed using the Bytes field.

Returns:



249
250
251
252
253
254
255
256
257
# File 'lib/aws-sdk-textract/types.rb', line 249

class AnalyzeDocumentRequest < Struct.new(
  :document,
  :feature_types,
  :human_loop_config,
  :queries_config,
  :adapters_config)
  SENSITIVE = []
  include Aws::Structure
end

#feature_typesArray<String>

A list of the types of analysis to perform. Add TABLES to the list to return information about the tables that are detected in the input document. Add FORMS to return detected form data. Add SIGNATURES to return the locations of detected signatures. Add LAYOUT to the list to return information about the layout of the document. All lines and words detected in the document are included in the response (including text that isn't related to the value of FeatureTypes).

Returns:

  • (Array<String>)


249
250
251
252
253
254
255
256
257
# File 'lib/aws-sdk-textract/types.rb', line 249

class AnalyzeDocumentRequest < Struct.new(
  :document,
  :feature_types,
  :human_loop_config,
  :queries_config,
  :adapters_config)
  SENSITIVE = []
  include Aws::Structure
end

#human_loop_configTypes::HumanLoopConfig

Sets the configuration for the human in the loop workflow for analyzing documents.

Amazon Textract uses Amazon Augmented AI (A2I) to run the human review workflows that you specify in HumanLoopConfig. A2I entered maintenance mode in July 2026 and no longer accepts new customers. If your account is not an existing A2I customer, requests fail with an InvalidParameterException. For more information, see AWS service availability. If you're an existing A2I customer but receive this error, contact AWS Support and request assistance from the A2I team.



249
250
251
252
253
254
255
256
257
# File 'lib/aws-sdk-textract/types.rb', line 249

class AnalyzeDocumentRequest < Struct.new(
  :document,
  :feature_types,
  :human_loop_config,
  :queries_config,
  :adapters_config)
  SENSITIVE = []
  include Aws::Structure
end

#queries_configTypes::QueriesConfig

Contains Queries and the alias for those Queries, as determined by the input.



249
250
251
252
253
254
255
256
257
# File 'lib/aws-sdk-textract/types.rb', line 249

class AnalyzeDocumentRequest < Struct.new(
  :document,
  :feature_types,
  :human_loop_config,
  :queries_config,
  :adapters_config)
  SENSITIVE = []
  include Aws::Structure
end