Class: Aws::Textract::Types::Block
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::Block
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
A Block represents items that are recognized in a document within a group of pixels close to each other. The information returned in a Block depends on the type of operation. In document-text detection (for example DetectDocumentText), you get information about the detected words and lines of text. In text analysis (for example AnalyzeDocument), you can also get information about the fields, tables and selection elements that are detected in the document.
An array of Block objects is returned by both synchronous and asynchronous operations. In synchronous operations, such as DetectDocumentText, the array of Block objects is the entire set of results. In asynchronous operations, such as GetDocumentAnalysis, the array is returned over one or more responses.
For more information, see [How Amazon Textract Works].
[1]: docs.aws.amazon.com/textract/latest/dg/how-it-works.html
Instance Attribute Summary collapse
-
#block_type ⇒ String
The type of text that’s recognized in a block.
-
#column_index ⇒ Integer
The column in which a table cell appears.
-
#column_span ⇒ Integer
The number of columns that a table cell spans.
-
#confidence ⇒ Float
The confidence that Amazon Textract has in the accuracy of the recognized text and the accuracy of the geometry points around the recognized text.
-
#entity_types ⇒ Array<String>
The type of entity.
-
#geometry ⇒ Types::Geometry
The location of the recognized text on the image.
-
#id ⇒ String
The identifier for the recognized text.
-
#page ⇒ Integer
The page in which a block was detected.
-
#relationships ⇒ Array<Types::Relationship>
A list of child blocks of the current block.
-
#row_index ⇒ Integer
The row in which a table cell is located.
-
#row_span ⇒ Integer
The number of rows that a table spans.
-
#selection_status ⇒ String
The selection status of a selectable element such as a radio button or checkbox.
-
#text ⇒ String
The word or line of text that’s recognized by Amazon Textract.
Instance Attribute Details
#block_type ⇒ String
The type of text that’s recognized in a block. In text-detection operations, the following types are returned:
-
PAGE - Contains a list of the LINE Block objects that are detected on a document page.
-
WORD - A word detected on a document page. A word is one or more ISO basic Latin script characters that aren’t separated by spaces.
-
LINE - A string of tab-delimited, contiguous words that’s detected on a document page.
In text analysis operations, the following types are returned:
-
PAGE - Contains a list of child Block objects that are detected on a document page.
-
KEY_VALUE_SET - Stores the KEY and VALUE Block objects for a field that’s detected on a document page. Use the
EntityTypefield to determine if a KEY_VALUE_SET object is a KEY Block object or a VALUE Block object. -
WORD - A word detected on a document page. A word is one or more ISO basic Latin script characters that aren’t separated by spaces that’s detected on a document page.
-
LINE - A string of tab-delimited, contiguous words that’s detected on a document page.
-
TABLE - A table that’s detected on a document page. A table is any grid-based information with 2 or more rows or columns with a cell span of 1 row and 1 column each.
-
CELL - A cell within a detected table. The cell is the parent of the block that contains the text in the cell.
-
SELECTION_ELEMENT - A selectable element such as a radio button or checkbox that’s detected on a document page. Use the value of
SelectionStatusto determine the status of the selection element.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#column_index ⇒ Integer
The column in which a table cell appears. The first column position is 1. ColumnIndex isn’t returned by DetectDocumentText and GetDocumentTextDetection.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#column_span ⇒ Integer
The number of columns that a table cell spans. ColumnSpan isn’t returned by DetectDocumentText and GetDocumentTextDetection.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#confidence ⇒ Float
The confidence that Amazon Textract has in the accuracy of the recognized text and the accuracy of the geometry points around the recognized text.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#entity_types ⇒ Array<String>
The type of entity. The following can be returned:
-
KEY - An identifier for a field on the document.
-
VALUE - The field text.
EntityTypes isn’t returned by DetectDocumentText and GetDocumentTextDetection.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#geometry ⇒ Types::Geometry
The location of the recognized text on the image. It includes an axis-aligned, coarse bounding box that surrounds the text, and a finer-grain polygon for more accurate spatial information.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#id ⇒ String
The identifier for the recognized text. The identifier is only unique for a single operation.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#page ⇒ Integer
The page in which a block was detected. Page is returned by asynchronous operations. Page values greater than 1 are only returned for multi-page documents that are in PDF format. A scanned image (JPG/PNG), even if it contains multiple document pages, is always considered to be a single-page document and the value of Page is always 1. Synchronous operations don’t return Page as every input document is considered to be a single-page document.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#relationships ⇒ Array<Types::Relationship>
A list of child blocks of the current block. For example a LINE object has child blocks for each WORD block that’s part of the line of text. There aren’t Relationship objects in the list for relationships that don’t exist, such as when the current block has no child blocks. The list size can be the following:
-
0 - The block has no child blocks.
-
1 - The block has child blocks.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#row_index ⇒ Integer
The row in which a table cell is located. The first row position is
-
RowIndexisn’t returned byDetectDocumentTextand
GetDocumentTextDetection.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#row_span ⇒ Integer
The number of rows that a table spans. RowSpan isn’t returned by DetectDocumentText and GetDocumentTextDetection.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#selection_status ⇒ String
The selection status of a selectable element such as a radio button or checkbox.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |
#text ⇒ String
The word or line of text that’s recognized by Amazon Textract.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-textract/types.rb', line 216 class Block < Struct.new( :block_type, :confidence, :text, :row_index, :column_index, :row_span, :column_span, :geometry, :id, :relationships, :entity_types, :selection_status, :page) include Aws::Structure end |