Class: Aws::Textract::Types::CreateAdapterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::CreateAdapterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#adapter_name ⇒ String
The name to be assigned to the adapter being created.
-
#auto_update ⇒ String
Controls whether or not the adapter should automatically update.
-
#client_request_token ⇒ String
Idempotent token is used to recognize the request.
-
#description ⇒ String
The description to be assigned to the adapter being created.
-
#feature_types ⇒ Array<String>
The type of feature that the adapter is being trained on.
-
#tags ⇒ Hash<String,String>
A list of tags to be added to the adapter.
Instance Attribute Details
#adapter_name ⇒ String
The name to be assigned to the adapter being created.
747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-textract/types.rb', line 747 class CreateAdapterRequest < Struct.new( :adapter_name, :client_request_token, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#auto_update ⇒ String
Controls whether or not the adapter should automatically update.
747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-textract/types.rb', line 747 class CreateAdapterRequest < Struct.new( :adapter_name, :client_request_token, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#client_request_token ⇒ String
Idempotent token is used to recognize the request. If the same token is used with multiple CreateAdapter requests, the same session is returned. This token is employed to avoid unintentionally creating the same session multiple times.
A suitable default value is auto-generated. You should normally not need to pass this option.
747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-textract/types.rb', line 747 class CreateAdapterRequest < Struct.new( :adapter_name, :client_request_token, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description to be assigned to the adapter being created.
747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-textract/types.rb', line 747 class CreateAdapterRequest < Struct.new( :adapter_name, :client_request_token, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_types ⇒ Array<String>
The type of feature that the adapter is being trained on. Currrenly,
supported feature types are: QUERIES
747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-textract/types.rb', line 747 class CreateAdapterRequest < Struct.new( :adapter_name, :client_request_token, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of tags to be added to the adapter.
747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-textract/types.rb', line 747 class CreateAdapterRequest < Struct.new( :adapter_name, :client_request_token, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |