Class: Aws::Textract::Types::DetectDocumentTextResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#blocksArray<Types::Block>

An array of Block objects containing the text detected in the document.

Returns:



323
324
325
326
327
# File 'lib/aws-sdk-textract/types.rb', line 323

class DetectDocumentTextResponse < Struct.new(
  :document_metadata,
  :blocks)
  include Aws::Structure
end

#document_metadataTypes::DocumentMetadata

Metadata about the document. Contains the number of pages that are detected in the document.



323
324
325
326
327
# File 'lib/aws-sdk-textract/types.rb', line 323

class DetectDocumentTextResponse < Struct.new(
  :document_metadata,
  :blocks)
  include Aws::Structure
end