Class: Aws::Textract::Types::Extraction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Contains information extracted by an analysis operation after using StartLendingAnalysis.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expense_document ⇒ Types::ExpenseDocument

The structure holding all the information returned by AnalyzeExpense

Returns:



1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-textract/types.rb', line 1315

class Extraction < Struct.new(
  :lending_document,
  :expense_document,
  :identity_document)
  SENSITIVE = []
  include Aws::Structure
end

#identity_document ⇒ Types::IdentityDocument

The structure that lists each document processed in an AnalyzeID operation.

Returns:



1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-textract/types.rb', line 1315

class Extraction < Struct.new(
  :lending_document,
  :expense_document,
  :identity_document)
  SENSITIVE = []
  include Aws::Structure
end

#lending_document ⇒ Types::LendingDocument

Holds the structured data returned by AnalyzeDocument for lending documents.

Returns:



1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-textract/types.rb', line 1315

class Extraction < Struct.new(
  :lending_document,
  :expense_document,
  :identity_document)
  SENSITIVE = []
  include Aws::Structure
end