Class: Aws::Textract::Types::Geometry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Information about where the following items are located on a document page: detected page, text, key-value pairs, tables, table cells, and selection elements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bounding_boxTypes::BoundingBox

An axis-aligned coarse representation of the location of the recognized item on the document page.

Returns:



1344
1345
1346
1347
1348
1349
1350
# File 'lib/aws-sdk-textract/types.rb', line 1344

class Geometry < Struct.new(
  :bounding_box,
  :polygon,
  :rotation_angle)
  SENSITIVE = []
  include Aws::Structure
end

#polygonArray<Types::Point>

Within the bounding box, a fine-grained polygon around the recognized item.

Returns:



1344
1345
1346
1347
1348
1349
1350
# File 'lib/aws-sdk-textract/types.rb', line 1344

class Geometry < Struct.new(
  :bounding_box,
  :polygon,
  :rotation_angle)
  SENSITIVE = []
  include Aws::Structure
end

#rotation_angleFloat

Provides a numerical value corresponding to the rotation of the WORD block. Possible values are 0, 90, 180, and 270.

Returns:

  • (Float)


1344
1345
1346
1347
1348
1349
1350
# File 'lib/aws-sdk-textract/types.rb', line 1344

class Geometry < Struct.new(
  :bounding_box,
  :polygon,
  :rotation_angle)
  SENSITIVE = []
  include Aws::Structure
end