Class: Aws::Textract::Types::GetAdapterResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::GetAdapterResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#adapter_id ⇒ String
A string identifying the adapter that information has been retrieved for.
-
#adapter_name ⇒ String
The name of the requested adapter.
-
#auto_update ⇒ String
Binary value indicating if the adapter is being automatically updated or not.
-
#creation_time ⇒ Time
The date and time the requested adapter was created at.
-
#description ⇒ String
The description for the requested adapter.
-
#feature_types ⇒ Array<String>
List of the targeted feature types for the requested adapter.
-
#tags ⇒ Hash<String,String>
A set of tags (key-value pairs) associated with the adapter that has been retrieved.
Instance Attribute Details
#adapter_id ⇒ String
A string identifying the adapter that information has been retrieved for.
1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-textract/types.rb', line 1397 class GetAdapterResponse < Struct.new( :adapter_id, :adapter_name, :creation_time, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#adapter_name ⇒ String
The name of the requested adapter.
1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-textract/types.rb', line 1397 class GetAdapterResponse < Struct.new( :adapter_id, :adapter_name, :creation_time, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#auto_update ⇒ String
Binary value indicating if the adapter is being automatically updated or not.
1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-textract/types.rb', line 1397 class GetAdapterResponse < Struct.new( :adapter_id, :adapter_name, :creation_time, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The date and time the requested adapter was created at.
1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-textract/types.rb', line 1397 class GetAdapterResponse < Struct.new( :adapter_id, :adapter_name, :creation_time, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the requested adapter.
1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-textract/types.rb', line 1397 class GetAdapterResponse < Struct.new( :adapter_id, :adapter_name, :creation_time, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_types ⇒ Array<String>
List of the targeted feature types for the requested adapter.
1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-textract/types.rb', line 1397 class GetAdapterResponse < Struct.new( :adapter_id, :adapter_name, :creation_time, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A set of tags (key-value pairs) associated with the adapter that has been retrieved.
1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-textract/types.rb', line 1397 class GetAdapterResponse < Struct.new( :adapter_id, :adapter_name, :creation_time, :description, :feature_types, :auto_update, :tags) SENSITIVE = [] include Aws::Structure end |