Class: Aws::Textract::Types::GetDocumentAnalysisResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::GetDocumentAnalysisResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #analyze_document_model_version ⇒ String
-
#blocks ⇒ Array<Types::Block>
The results of the text-analysis operation.
-
#document_metadata ⇒ Types::DocumentMetadata
Information about a document that Amazon Textract processed.
-
#job_status ⇒ String
The current status of the text detection job.
-
#next_token ⇒ String
If the response is truncated, Amazon Textract returns this token.
-
#status_message ⇒ String
Returns if the detection job could not be completed.
-
#warnings ⇒ Array<Types::Warning>
A list of warnings that occurred during the document-analysis operation.
Instance Attribute Details
#analyze_document_model_version ⇒ String
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-textract/types.rb', line 1589 class GetDocumentAnalysisResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message, :analyze_document_model_version) SENSITIVE = [] include Aws::Structure end |
#blocks ⇒ Array<Types::Block>
The results of the text-analysis operation.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-textract/types.rb', line 1589 class GetDocumentAnalysisResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message, :analyze_document_model_version) SENSITIVE = [] include Aws::Structure end |
#document_metadata ⇒ Types::DocumentMetadata
Information about a document that Amazon Textract processed.
DocumentMetadata is returned in every page of paginated responses
from an Amazon Textract video operation.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-textract/types.rb', line 1589 class GetDocumentAnalysisResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message, :analyze_document_model_version) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The current status of the text detection job.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-textract/types.rb', line 1589 class GetDocumentAnalysisResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message, :analyze_document_model_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response is truncated, Amazon Textract returns this token. You can use this token in the subsequent request to retrieve the next set of text detection results.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-textract/types.rb', line 1589 class GetDocumentAnalysisResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message, :analyze_document_model_version) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
Returns if the detection job could not be completed. Contains explanation for what error occured.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-textract/types.rb', line 1589 class GetDocumentAnalysisResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message, :analyze_document_model_version) SENSITIVE = [] include Aws::Structure end |
#warnings ⇒ Array<Types::Warning>
A list of warnings that occurred during the document-analysis operation.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-textract/types.rb', line 1589 class GetDocumentAnalysisResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message, :analyze_document_model_version) SENSITIVE = [] include Aws::Structure end |