Class: Aws::Textract::Types::GetDocumentTextDetectionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blocksArray<Types::Block>

The results of the text-detection operation.

Returns:



1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'lib/aws-sdk-textract/types.rb', line 1666

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message,
  :detect_document_text_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#detect_document_text_model_versionString

Returns:

  • (String)


1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'lib/aws-sdk-textract/types.rb', line 1666

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message,
  :detect_document_text_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#document_metadataTypes::DocumentMetadata

Information about a document that Amazon Textract processed. DocumentMetadata is returned in every page of paginated responses from an Amazon Textract video operation.



1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'lib/aws-sdk-textract/types.rb', line 1666

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message,
  :detect_document_text_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The current status of the text detection job.

Returns:

  • (String)


1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'lib/aws-sdk-textract/types.rb', line 1666

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message,
  :detect_document_text_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response is truncated, Amazon Textract returns this token. You can use this token in the subsequent request to retrieve the next set of text-detection results.

Returns:

  • (String)


1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'lib/aws-sdk-textract/types.rb', line 1666

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message,
  :detect_document_text_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

Returns if the detection job could not be completed. Contains explanation for what error occured.

Returns:

  • (String)


1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'lib/aws-sdk-textract/types.rb', line 1666

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message,
  :detect_document_text_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#warningsArray<Types::Warning>

A list of warnings that occurred during the text-detection operation for the document.

Returns:



1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'lib/aws-sdk-textract/types.rb', line 1666

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message,
  :detect_document_text_model_version)
  SENSITIVE = []
  include Aws::Structure
end