Class: Aws::Textract::Types::GetLendingAnalysisResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analyze_lending_model_versionString

The current model version of the Analyze Lending API.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-textract/types.rb', line 1820

class GetLendingAnalysisResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :results,
  :warnings,
  :status_message,
  :analyze_lending_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#document_metadataTypes::DocumentMetadata

Information about the input document.



1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-textract/types.rb', line 1820

class GetLendingAnalysisResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :results,
  :warnings,
  :status_message,
  :analyze_lending_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The current status of the lending analysis job.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-textract/types.rb', line 1820

class GetLendingAnalysisResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :results,
  :warnings,
  :status_message,
  :analyze_lending_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response is truncated, Amazon Textract returns this token. You can use this token in the subsequent request to retrieve the next set of lending results.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-textract/types.rb', line 1820

class GetLendingAnalysisResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :results,
  :warnings,
  :status_message,
  :analyze_lending_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#resultsArray<Types::LendingResult>

Holds the information returned by one of AmazonTextract's document analysis operations for the pinstripe.

Returns:



1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-textract/types.rb', line 1820

class GetLendingAnalysisResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :results,
  :warnings,
  :status_message,
  :analyze_lending_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

Returns if the lending analysis job could not be completed. Contains explanation for what error occurred.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-textract/types.rb', line 1820

class GetLendingAnalysisResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :results,
  :warnings,
  :status_message,
  :analyze_lending_model_version)
  SENSITIVE = []
  include Aws::Structure
end

#warningsArray<Types::Warning>

A list of warnings that occurred during the lending analysis operation.

Returns:



1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-textract/types.rb', line 1820

class GetLendingAnalysisResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :results,
  :warnings,
  :status_message,
  :analyze_lending_model_version)
  SENSITIVE = []
  include Aws::Structure
end