Class: Aws::Textract::Types::NotificationChannel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Note:

When making an API call, you may pass NotificationChannel data as a hash:

{
  sns_topic_arn: "SNSTopicArn", # required
  role_arn: "RoleArn", # required
}

The Amazon Simple Notification Service (Amazon SNS) topic to which Amazon Textract publishes the completion status of an asynchronous document operation, such as StartDocumentTextDetection.

Instance Attribute Summary collapse

Instance Attribute Details

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that gives Amazon Textract publishing permissions to the Amazon SNS topic.

Returns:

  • (String)


630
631
632
633
634
# File 'lib/aws-sdk-textract/types.rb', line 630

class NotificationChannel < Struct.new(
  :sns_topic_arn,
  :role_arn)
  include Aws::Structure
end

#sns_topic_arnString

The Amazon SNS topic that Amazon Textract posts the completion status to.

Returns:

  • (String)


630
631
632
633
634
# File 'lib/aws-sdk-textract/types.rb', line 630

class NotificationChannel < Struct.new(
  :sns_topic_arn,
  :role_arn)
  include Aws::Structure
end