Class: Aws::Textract::Types::S3Object

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

The S3 bucket name and file name that identifies the document.

The AWS Region for the S3 bucket that contains the document must match the Region that you use for Amazon Textract operations.

For Amazon Textract to process a file in an S3 bucket, the user must have permission to access the S3 bucket and file.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the S3 bucket. Note that the # character is not valid in the file name.

Returns:

  • (String)


2702
2703
2704
2705
2706
2707
2708
# File 'lib/aws-sdk-textract/types.rb', line 2702

class S3Object < Struct.new(
  :bucket,
  :name,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The file name of the input document. Image files may be in PDF, TIFF, JPEG, or PNG format.

Returns:

  • (String)


2702
2703
2704
2705
2706
2707
2708
# File 'lib/aws-sdk-textract/types.rb', line 2702

class S3Object < Struct.new(
  :bucket,
  :name,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

If the bucket has versioning enabled, you can specify the object version.

Returns:

  • (String)


2702
2703
2704
2705
2706
2707
2708
# File 'lib/aws-sdk-textract/types.rb', line 2702

class S3Object < Struct.new(
  :bucket,
  :name,
  :version)
  SENSITIVE = []
  include Aws::Structure
end