Class: Aws::Textract::Types::StartDocumentAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Note:

When making an API call, you may pass StartDocumentAnalysisRequest data as a hash:

{
  document_location: { # required
    s3_object: {
      bucket: "S3Bucket",
      name: "S3ObjectName",
      version: "S3ObjectVersion",
    },
  },
  feature_types: ["TABLES"], # required, accepts TABLES, FORMS
  client_request_token: "ClientRequestToken",
  job_tag: "JobTag",
  notification_channel: {
    sns_topic_arn: "SNSTopicArn", # required
    role_arn: "RoleArn", # required
  },
}

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

The idempotent token that you use to identify the start request. If you use the same token with multiple StartDocumentAnalysis requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidentally started more than once.



783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-textract/types.rb', line 783

class StartDocumentAnalysisRequest < Struct.new(
  :document_location,
  :feature_types,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end

#document_locationTypes::DocumentLocation

The location of the document to be processed.



783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-textract/types.rb', line 783

class StartDocumentAnalysisRequest < Struct.new(
  :document_location,
  :feature_types,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end

#feature_typesArray<String>

A list of the types of analysis to perform. Add TABLES to the list to return information about the tables that are detected in the input document. Add FORMS to return detected fields and the associated text. To perform both types of analysis, add TABLES and FORMS to FeatureTypes. All selectable elements (SELECTION_ELEMENT) that are detected are returned, whatever the value of FeatureTypes.



783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-textract/types.rb', line 783

class StartDocumentAnalysisRequest < Struct.new(
  :document_location,
  :feature_types,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end

#job_tagString

An identifier you specify that’s included in the completion notification that’s published to the Amazon SNS topic. For example, you can use JobTag to identify the type of document, such as a tax form or a receipt, that the completion notification corresponds to.



783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-textract/types.rb', line 783

class StartDocumentAnalysisRequest < Struct.new(
  :document_location,
  :feature_types,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end

#notification_channelTypes::NotificationChannel

The Amazon SNS topic ARN that you want Amazon Textract to publish the completion status of the operation to.



783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-textract/types.rb', line 783

class StartDocumentAnalysisRequest < Struct.new(
  :document_location,
  :feature_types,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end