Class: Aws::Textract::Types::StartDocumentTextDetectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Note:

When making an API call, you may pass StartDocumentTextDetectionRequest data as a hash:

{
  document_location: { # required
    s3_object: {
      bucket: "S3Bucket",
      name: "S3ObjectName",
      version: "S3ObjectVersion",
    },
  },
  client_request_token: "ClientRequestToken",
  job_tag: "JobTag",
  notification_channel: {
    sns_topic_arn: "SNSTopicArn", # required
    role_arn: "RoleArn", # required
  },
}

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

The idempotent token that’s used to identify the start request. If you use the same token with multiple StartDocumentTextDetection requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidentally started more than once.

Returns:

  • (String)


848
849
850
851
852
853
854
# File 'lib/aws-sdk-textract/types.rb', line 848

class StartDocumentTextDetectionRequest < Struct.new(
  :document_location,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end

#document_locationTypes::DocumentLocation

The location of the document to be processed.



848
849
850
851
852
853
854
# File 'lib/aws-sdk-textract/types.rb', line 848

class StartDocumentTextDetectionRequest < Struct.new(
  :document_location,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end

#job_tagString

An identifier you specify that’s included in the completion notification that’s published to the Amazon SNS topic. For example, you can use JobTag to identify the type of document, such as a tax form or a receipt, that the completion notification corresponds to.

Returns:

  • (String)


848
849
850
851
852
853
854
# File 'lib/aws-sdk-textract/types.rb', line 848

class StartDocumentTextDetectionRequest < Struct.new(
  :document_location,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end

#notification_channelTypes::NotificationChannel

The Amazon SNS topic ARN that you want Amazon Textract to publish the completion status of the operation to.



848
849
850
851
852
853
854
# File 'lib/aws-sdk-textract/types.rb', line 848

class StartDocumentTextDetectionRequest < Struct.new(
  :document_location,
  :client_request_token,
  :job_tag,
  :notification_channel)
  include Aws::Structure
end