Class: Aws::Textract::Types::UpdateAdapterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::UpdateAdapterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#adapter_id ⇒ String
A string containing a unique ID for the adapter that will be updated.
-
#adapter_name ⇒ String
The new name to be applied to the adapter.
-
#auto_update ⇒ String
The new auto-update status to be applied to the adapter.
-
#description ⇒ String
The new description to be applied to the adapter.
Instance Attribute Details
#adapter_id ⇒ String
A string containing a unique ID for the adapter that will be updated.
3186 3187 3188 3189 3190 3191 3192 3193 |
# File 'lib/aws-sdk-textract/types.rb', line 3186 class UpdateAdapterRequest < Struct.new( :adapter_id, :description, :adapter_name, :auto_update) SENSITIVE = [] include Aws::Structure end |
#adapter_name ⇒ String
The new name to be applied to the adapter.
3186 3187 3188 3189 3190 3191 3192 3193 |
# File 'lib/aws-sdk-textract/types.rb', line 3186 class UpdateAdapterRequest < Struct.new( :adapter_id, :description, :adapter_name, :auto_update) SENSITIVE = [] include Aws::Structure end |
#auto_update ⇒ String
The new auto-update status to be applied to the adapter.
3186 3187 3188 3189 3190 3191 3192 3193 |
# File 'lib/aws-sdk-textract/types.rb', line 3186 class UpdateAdapterRequest < Struct.new( :adapter_id, :description, :adapter_name, :auto_update) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The new description to be applied to the adapter.
3186 3187 3188 3189 3190 3191 3192 3193 |
# File 'lib/aws-sdk-textract/types.rb', line 3186 class UpdateAdapterRequest < Struct.new( :adapter_id, :description, :adapter_name, :auto_update) SENSITIVE = [] include Aws::Structure end |