Class: Aws::Textract::Types::UpdateAdapterResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#adapter_idString

A string containing a unique ID for the adapter that has been updated.

Returns:

  • (String)


3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
# File 'lib/aws-sdk-textract/types.rb', line 3224

class UpdateAdapterResponse < Struct.new(
  :adapter_id,
  :adapter_name,
  :creation_time,
  :description,
  :feature_types,
  :auto_update)
  SENSITIVE = []
  include Aws::Structure
end

#adapter_nameString

A string containing the name of the adapter that has been updated.

Returns:

  • (String)


3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
# File 'lib/aws-sdk-textract/types.rb', line 3224

class UpdateAdapterResponse < Struct.new(
  :adapter_id,
  :adapter_name,
  :creation_time,
  :description,
  :feature_types,
  :auto_update)
  SENSITIVE = []
  include Aws::Structure
end

#auto_updateString

The auto-update status of the adapter that has been updated.

Returns:

  • (String)


3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
# File 'lib/aws-sdk-textract/types.rb', line 3224

class UpdateAdapterResponse < Struct.new(
  :adapter_id,
  :adapter_name,
  :creation_time,
  :description,
  :feature_types,
  :auto_update)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

An object specifying the creation time of the the adapter that has been updated.

Returns:

  • (Time)


3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
# File 'lib/aws-sdk-textract/types.rb', line 3224

class UpdateAdapterResponse < Struct.new(
  :adapter_id,
  :adapter_name,
  :creation_time,
  :description,
  :feature_types,
  :auto_update)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A string containing the description of the adapter that has been updated.

Returns:

  • (String)


3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
# File 'lib/aws-sdk-textract/types.rb', line 3224

class UpdateAdapterResponse < Struct.new(
  :adapter_id,
  :adapter_name,
  :creation_time,
  :description,
  :feature_types,
  :auto_update)
  SENSITIVE = []
  include Aws::Structure
end

#feature_typesArray<String>

List of the targeted feature types for the updated adapter.

Returns:

  • (Array<String>)


3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
# File 'lib/aws-sdk-textract/types.rb', line 3224

class UpdateAdapterResponse < Struct.new(
  :adapter_id,
  :adapter_name,
  :creation_time,
  :description,
  :feature_types,
  :auto_update)
  SENSITIVE = []
  include Aws::Structure
end