Class: Aws::Textract::Types::Warning

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

A warning about an issue that occurred during asynchronous text analysis (StartDocumentAnalysis) or asynchronous document-text detection (StartDocumentTextDetection).

Instance Attribute Summary collapse

Instance Attribute Details

#error_codeString

The error code for the warning.

Returns:



882
883
884
885
886
# File 'lib/aws-sdk-textract/types.rb', line 882

class Warning < Struct.new(
  :error_code,
  :pages)
  include Aws::Structure
end

#pagesArray<Integer>

A list of the pages that the warning applies to.

Returns:



882
883
884
885
886
# File 'lib/aws-sdk-textract/types.rb', line 882

class Warning < Struct.new(
  :error_code,
  :pages)
  include Aws::Structure
end