Class: Aws::Textract::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Textract::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-textract/client.rb
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#analyze_document(params = {}) ⇒ Types::AnalyzeDocumentResponse
Analyzes an input document for relationships between detected items.
-
#detect_document_text(params = {}) ⇒ Types::DetectDocumentTextResponse
Detects text in the input document.
-
#get_document_analysis(params = {}) ⇒ Types::GetDocumentAnalysisResponse
Gets the results for an Amazon Textract asynchronous operation that analyzes text in a document.
-
#get_document_text_detection(params = {}) ⇒ Types::GetDocumentTextDetectionResponse
Gets the results for an Amazon Textract asynchronous operation that detects text in a document.
-
#start_document_analysis(params = {}) ⇒ Types::StartDocumentAnalysisResponse
Starts asynchronous analysis of an input document for relationships between detected items such as key and value pairs, tables, and selection elements.
-
#start_document_text_detection(params = {}) ⇒ Types::StartDocumentTextDetectionResponse
Starts the asynchronous detection of text in a document.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
261 262 263 |
# File 'lib/aws-sdk-textract/client.rb', line 261 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
887 888 889 |
# File 'lib/aws-sdk-textract/client.rb', line 887 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
890 891 892 |
# File 'lib/aws-sdk-textract/client.rb', line 890 def errors_module Errors end |
Instance Method Details
#analyze_document(params = {}) ⇒ Types::AnalyzeDocumentResponse
Analyzes an input document for relationships between detected items.
The types of information returned are as follows:
-
Words and lines that are related to nearby lines and words. The related information is returned in two Block objects each of type
KEY_VALUE_SET: a KEY Block object and a VALUE Block object. For example, *Name: Ana Silva Carolina* contains a key and value. Name: is the key. *Ana Silva Carolina* is the value. -
Table and table cell data. A TABLE Block object contains information about a detected table. A CELL Block object is returned for each cell in a table.
-
Selectable elements such as checkboxes and radio buttons. A SELECTION_ELEMENT Block object contains information about a selectable element.
-
Lines and words of text. A LINE Block object contains one or more WORD Block objects.
You can choose which type of analysis to perform by specifying the FeatureTypes list.
The output is returned in a list of BLOCK objects.
AnalyzeDocument is a synchronous operation. To analyze documents asynchronously, use StartDocumentAnalysis.
For more information, see [Document Text Analysis].
[1]: docs.aws.amazon.com/textract/latest/dg/how-it-works-analyzing.html
368 369 370 371 |
# File 'lib/aws-sdk-textract/client.rb', line 368 def analyze_document(params = {}, = {}) req = build_request(:analyze_document, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
865 866 867 868 869 870 871 872 873 874 875 876 |
# File 'lib/aws-sdk-textract/client.rb', line 865 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-textract' context[:gem_version] = '1.10.0' Seahorse::Client::Request.new(handlers, context) end |
#detect_document_text(params = {}) ⇒ Types::DetectDocumentTextResponse
Detects text in the input document. Amazon Textract can detect lines of text and the words that make up a line of text. The input document must be an image in JPG or PNG format. DetectDocumentText returns the detected text in an array of Block objects.
Each document page has as an associated Block of type PAGE. Each PAGE Block object is the parent of LINE Block objects that represent the lines of detected text on a page. A LINE Block object is a parent for each word that makes up the line. Words are represented by Block objects of type WORD.
DetectDocumentText is a synchronous operation. To analyze documents asynchronously, use StartDocumentTextDetection.
For more information, see [Document Text Detection].
[1]: docs.aws.amazon.com/textract/latest/dg/how-it-works-detecting.html
451 452 453 454 |
# File 'lib/aws-sdk-textract/client.rb', line 451 def detect_document_text(params = {}, = {}) req = build_request(:detect_document_text, params) req.send_request() end |
#get_document_analysis(params = {}) ⇒ Types::GetDocumentAnalysisResponse
Gets the results for an Amazon Textract asynchronous operation that analyzes text in a document.
You start asynchronous text analysis by calling StartDocumentAnalysis, which returns a job identifier (JobId). When the text analysis operation finishes, Amazon Textract publishes a completion status to the Amazon Simple Notification Service (Amazon SNS) topic that’s registered in the initial call to StartDocumentAnalysis. To get the results of the text-detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetDocumentAnalysis, and pass the job identifier (JobId) from the initial call to StartDocumentAnalysis.
GetDocumentAnalysis returns an array of Block objects. The following types of information are returned:
-
Words and lines that are related to nearby lines and words. The related information is returned in two Block objects each of type
KEY_VALUE_SET: a KEY Block object and a VALUE Block object. For example, *Name: Ana Silva Carolina* contains a key and value. Name: is the key. *Ana Silva Carolina* is the value. -
Table and table cell data. A TABLE Block object contains information about a detected table. A CELL Block object is returned for each cell in a table.
-
Selectable elements such as checkboxes and radio buttons. A SELECTION_ELEMENT Block object contains information about a selectable element.
-
Lines and words of text. A LINE Block object contains one or more WORD Block objects.
Use the MaxResults parameter to limit the number of blocks returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetDocumentAnalysis, and populate the NextToken request parameter with the token value that’s returned from the previous call to GetDocumentAnalysis.
For more information, see [Document Text Analysis].
[1]: docs.aws.amazon.com/textract/latest/dg/how-it-works-analyzing.html
575 576 577 578 |
# File 'lib/aws-sdk-textract/client.rb', line 575 def get_document_analysis(params = {}, = {}) req = build_request(:get_document_analysis, params) req.send_request() end |
#get_document_text_detection(params = {}) ⇒ Types::GetDocumentTextDetectionResponse
Gets the results for an Amazon Textract asynchronous operation that detects text in a document. Amazon Textract can detect lines of text and the words that make up a line of text.
You start asynchronous text detection by calling StartDocumentTextDetection, which returns a job identifier (JobId). When the text detection operation finishes, Amazon Textract publishes a completion status to the Amazon Simple Notification Service (Amazon SNS) topic that’s registered in the initial call to StartDocumentTextDetection. To get the results of the text-detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetDocumentTextDetection, and pass the job identifier (JobId) from the initial call to StartDocumentTextDetection.
GetDocumentTextDetection returns an array of Block objects.
Each document page has as an associated Block of type PAGE. Each PAGE Block object is the parent of LINE Block objects that represent the lines of detected text on a page. A LINE Block object is a parent for each word that makes up the line. Words are represented by Block objects of type WORD.
Use the MaxResults parameter to limit the number of blocks that are returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetDocumentTextDetection, and populate the NextToken request parameter with the token value that’s returned from the previous call to GetDocumentTextDetection.
For more information, see [Document Text Detection].
[1]: docs.aws.amazon.com/textract/latest/dg/how-it-works-detecting.html
689 690 691 692 |
# File 'lib/aws-sdk-textract/client.rb', line 689 def get_document_text_detection(params = {}, = {}) req = build_request(:get_document_text_detection, params) req.send_request() end |
#start_document_analysis(params = {}) ⇒ Types::StartDocumentAnalysisResponse
Starts asynchronous analysis of an input document for relationships between detected items such as key and value pairs, tables, and selection elements.
StartDocumentAnalysis can analyze text in documents that are in JPG, PNG, and PDF format. The documents are stored in an Amazon S3 bucket. Use DocumentLocation to specify the bucket name and file name of the document.
StartDocumentAnalysis returns a job identifier (JobId) that you use to get the results of the operation. When text analysis is finished, Amazon Textract publishes a completion status to the Amazon Simple Notification Service (Amazon SNS) topic that you specify in NotificationChannel. To get the results of the text analysis operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetDocumentAnalysis, and pass the job identifier (JobId) from the initial call to StartDocumentAnalysis.
For more information, see [Document Text Analysis].
[1]: docs.aws.amazon.com/textract/latest/dg/how-it-works-analyzing.html
777 778 779 780 |
# File 'lib/aws-sdk-textract/client.rb', line 777 def start_document_analysis(params = {}, = {}) req = build_request(:start_document_analysis, params) req.send_request() end |
#start_document_text_detection(params = {}) ⇒ Types::StartDocumentTextDetectionResponse
Starts the asynchronous detection of text in a document. Amazon Textract can detect lines of text and the words that make up a line of text.
StartDocumentTextDetection can analyze text in documents that are in JPG, PNG, and PDF format. The documents are stored in an Amazon S3 bucket. Use DocumentLocation to specify the bucket name and file name of the document.
StartTextDetection returns a job identifier (JobId) that you use to get the results of the operation. When text detection is finished, Amazon Textract publishes a completion status to the Amazon Simple Notification Service (Amazon SNS) topic that you specify in NotificationChannel. To get the results of the text detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetDocumentTextDetection, and pass the job identifier (JobId) from the initial call to StartDocumentTextDetection.
For more information, see [Document Text Detection].
[1]: docs.aws.amazon.com/textract/latest/dg/how-it-works-detecting.html
856 857 858 859 |
# File 'lib/aws-sdk-textract/client.rb', line 856 def start_document_text_detection(params = {}, = {}) req = build_request(:start_document_text_detection, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
880 881 882 |
# File 'lib/aws-sdk-textract/client.rb', line 880 def waiter_names [] end |