Class: Aws::Textract::Types::AnalyzeDocumentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::AnalyzeDocumentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
When making an API call, you may pass AnalyzeDocumentRequest data as a hash:
{
document: { # required
bytes: "data",
s3_object: {
bucket: "S3Bucket",
name: "S3ObjectName",
version: "S3ObjectVersion",
},
},
feature_types: ["TABLES"], # required, accepts TABLES, FORMS
}
Instance Attribute Summary collapse
-
#document ⇒ Types::Document
The input document as base64-encoded bytes or an Amazon S3 object.
-
#feature_types ⇒ Array<String>
A list of the types of analysis to perform.
Instance Attribute Details
#document ⇒ Types::Document
The input document as base64-encoded bytes or an Amazon S3 object. If you use the AWS CLI to call Amazon Textract operations, you can’t pass image bytes. The document must be an image in JPG or PNG format.
If you are using an AWS SDK to call Amazon Textract, you might not need to base64-encode image bytes passed using the Bytes field.
46 47 48 49 50 |
# File 'lib/aws-sdk-textract/types.rb', line 46 class AnalyzeDocumentRequest < Struct.new( :document, :feature_types) include Aws::Structure end |
#feature_types ⇒ Array<String>
A list of the types of analysis to perform. Add TABLES to the list to return information about the tables detected in the input document. Add FORMS to return detected fields and the associated text. To perform both types of analysis, add TABLES and FORMS to FeatureTypes.
46 47 48 49 50 |
# File 'lib/aws-sdk-textract/types.rb', line 46 class AnalyzeDocumentRequest < Struct.new( :document, :feature_types) include Aws::Structure end |