Class: Aws::Textract::Types::BoundingBox
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::BoundingBox
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
The bounding box around the recognized text, key, value, table or table cell on a document page. The left (x-coordinate) and top (y-coordinate) are coordinates that represent the top and left sides of the bounding box. Note that the upper-left corner of the image is the origin (0,0).
The top and left values returned are ratios of the overall document page size. For example, if the input image is 700 x 200 pixels, and the top-left coordinate of the bounding box is 350 x 50 pixels, the API returns a left value of 0.5 (350/700) and a top value of 0.25 (50/200).
The width and height values represent the dimensions of the bounding box as a ratio of the overall document page dimension. For example, if the document page size is 700 x 200 pixels, and the bounding box width is 70 pixels, the width returned is 0.1.
Instance Attribute Summary collapse
-
#height ⇒ Float
The height of the bounding box as a ratio of the overall document page height.
-
#left ⇒ Float
The left coordinate of the bounding box as a ratio of overall document page width.
-
#top ⇒ Float
The top coordinate of the bounding box as a ratio of overall document page height.
-
#width ⇒ Float
The width of the bounding box as a ratio of the overall document page width.
Instance Attribute Details
#height ⇒ Float
The height of the bounding box as a ratio of the overall document page height.
272 273 274 275 276 277 278 |
# File 'lib/aws-sdk-textract/types.rb', line 272 class BoundingBox < Struct.new( :width, :height, :left, :top) include Aws::Structure end |
#left ⇒ Float
The left coordinate of the bounding box as a ratio of overall document page width.
272 273 274 275 276 277 278 |
# File 'lib/aws-sdk-textract/types.rb', line 272 class BoundingBox < Struct.new( :width, :height, :left, :top) include Aws::Structure end |
#top ⇒ Float
The top coordinate of the bounding box as a ratio of overall document page height.
272 273 274 275 276 277 278 |
# File 'lib/aws-sdk-textract/types.rb', line 272 class BoundingBox < Struct.new( :width, :height, :left, :top) include Aws::Structure end |
#width ⇒ Float
The width of the bounding box as a ratio of the overall document page width.
272 273 274 275 276 277 278 |
# File 'lib/aws-sdk-textract/types.rb', line 272 class BoundingBox < Struct.new( :width, :height, :left, :top) include Aws::Structure end |