Class: Aws::Textract::Types::Geometry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Information about where a recognized text, key, value, table, or table cell is located on a document page.

Instance Attribute Summary collapse

Instance Attribute Details

#bounding_boxTypes::BoundingBox

An axis-aligned coarse representation of the location of the recognized text on the document page.

Returns:



443
444
445
446
447
# File 'lib/aws-sdk-textract/types.rb', line 443

class Geometry < Struct.new(
  :bounding_box,
  :polygon)
  include Aws::Structure
end

#polygonArray<Types::Point>

Within the bounding box, a fine-grained polygon around the recognized text.

Returns:



443
444
445
446
447
# File 'lib/aws-sdk-textract/types.rb', line 443

class Geometry < Struct.new(
  :bounding_box,
  :polygon)
  include Aws::Structure
end