Class: Aws::Textract::Types::Geometry
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::Geometry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Information about where a recognized text, key, value, table, or table cell is located on a document page.
Instance Attribute Summary collapse
-
#bounding_box ⇒ Types::BoundingBox
An axis-aligned coarse representation of the location of the recognized text on the document page.
-
#polygon ⇒ Array<Types::Point>
Within the bounding box, a fine-grained polygon around the recognized text.
Instance Attribute Details
#bounding_box ⇒ Types::BoundingBox
An axis-aligned coarse representation of the location of the recognized text on the document page.
443 444 445 446 447 |
# File 'lib/aws-sdk-textract/types.rb', line 443 class Geometry < Struct.new( :bounding_box, :polygon) include Aws::Structure end |
#polygon ⇒ Array<Types::Point>
Within the bounding box, a fine-grained polygon around the recognized text.
443 444 445 446 447 |
# File 'lib/aws-sdk-textract/types.rb', line 443 class Geometry < Struct.new( :bounding_box, :polygon) include Aws::Structure end |