Class: Aws::Textract::Types::GetDocumentTextDetectionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-textract/types.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#blocksArray<Types::Block>

The results of the text-detection operation.

Returns:



596
597
598
599
600
601
602
603
604
# File 'lib/aws-sdk-textract/types.rb', line 596

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message)
  include Aws::Structure
end

#document_metadataTypes::DocumentMetadata

Information about a document that Amazon Textract processed. DocumentMetadata is returned in every page of paginated responses from an Amazon Textract video operation.



596
597
598
599
600
601
602
603
604
# File 'lib/aws-sdk-textract/types.rb', line 596

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message)
  include Aws::Structure
end

#job_statusString

The current status of the text detection job.

Returns:

  • (String)


596
597
598
599
600
601
602
603
604
# File 'lib/aws-sdk-textract/types.rb', line 596

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message)
  include Aws::Structure
end

#next_tokenString

If the response is truncated, Amazon Textract returns this token. You can use this token in the subsequent request to retrieve the next set of text-detection results.

Returns:

  • (String)


596
597
598
599
600
601
602
603
604
# File 'lib/aws-sdk-textract/types.rb', line 596

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message)
  include Aws::Structure
end

#status_messageString

The current status of an asynchronous document text-detection operation.

Returns:

  • (String)


596
597
598
599
600
601
602
603
604
# File 'lib/aws-sdk-textract/types.rb', line 596

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message)
  include Aws::Structure
end

#warningsArray<Types::Warning>

A list of warnings that occurred during the document text-detection operation.

Returns:



596
597
598
599
600
601
602
603
604
# File 'lib/aws-sdk-textract/types.rb', line 596

class GetDocumentTextDetectionResponse < Struct.new(
  :document_metadata,
  :job_status,
  :next_token,
  :blocks,
  :warnings,
  :status_message)
  include Aws::Structure
end