Class: Aws::Textract::Types::GetDocumentTextDetectionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::GetDocumentTextDetectionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Instance Attribute Summary collapse
-
#blocks ⇒ Array<Types::Block>
The results of the text-detection operation.
-
#document_metadata ⇒ Types::DocumentMetadata
Information about a document that Amazon Textract processed.
-
#job_status ⇒ String
The current status of the text detection job.
-
#next_token ⇒ String
If the response is truncated, Amazon Textract returns this token.
-
#status_message ⇒ String
The current status of an asynchronous document text-detection operation.
-
#warnings ⇒ Array<Types::Warning>
A list of warnings that occurred during the document text-detection operation.
Instance Attribute Details
#blocks ⇒ Array<Types::Block>
The results of the text-detection operation.
596 597 598 599 600 601 602 603 604 |
# File 'lib/aws-sdk-textract/types.rb', line 596 class GetDocumentTextDetectionResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message) include Aws::Structure end |
#document_metadata ⇒ Types::DocumentMetadata
Information about a document that Amazon Textract processed. DocumentMetadata is returned in every page of paginated responses from an Amazon Textract video operation.
596 597 598 599 600 601 602 603 604 |
# File 'lib/aws-sdk-textract/types.rb', line 596 class GetDocumentTextDetectionResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message) include Aws::Structure end |
#job_status ⇒ String
The current status of the text detection job.
596 597 598 599 600 601 602 603 604 |
# File 'lib/aws-sdk-textract/types.rb', line 596 class GetDocumentTextDetectionResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message) include Aws::Structure end |
#next_token ⇒ String
If the response is truncated, Amazon Textract returns this token. You can use this token in the subsequent request to retrieve the next set of text-detection results.
596 597 598 599 600 601 602 603 604 |
# File 'lib/aws-sdk-textract/types.rb', line 596 class GetDocumentTextDetectionResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message) include Aws::Structure end |
#status_message ⇒ String
The current status of an asynchronous document text-detection operation.
596 597 598 599 600 601 602 603 604 |
# File 'lib/aws-sdk-textract/types.rb', line 596 class GetDocumentTextDetectionResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message) include Aws::Structure end |
#warnings ⇒ Array<Types::Warning>
A list of warnings that occurred during the document text-detection operation.
596 597 598 599 600 601 602 603 604 |
# File 'lib/aws-sdk-textract/types.rb', line 596 class GetDocumentTextDetectionResponse < Struct.new( :document_metadata, :job_status, :next_token, :blocks, :warnings, :status_message) include Aws::Structure end |