Class: Aws::Textract::Types::HumanLoopConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::HumanLoopConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Sets up the human review workflow the document will be sent to if one of the conditions is met. You can also set certain attributes of the image before review.
HumanLoopConfig. A2I entered
maintenance mode in July 2026 and no longer accepts new customers. If
your account is not an existing A2I customer, requests fail with an
InvalidParameterException. For more information, see AWS service
availability. If you're an existing A2I customer but receive this
error, contact AWS Support and request assistance from the A2I team.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_attributes ⇒ Types::HumanLoopDataAttributes
Sets attributes of the input data.
-
#flow_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the flow definition.
-
#human_loop_name ⇒ String
The name of the human workflow used for this image.
Instance Attribute Details
#data_attributes ⇒ Types::HumanLoopDataAttributes
Sets attributes of the input data.
1944 1945 1946 1947 1948 1949 1950 |
# File 'lib/aws-sdk-textract/types.rb', line 1944 class HumanLoopConfig < Struct.new( :human_loop_name, :flow_definition_arn, :data_attributes) SENSITIVE = [] include Aws::Structure end |
#flow_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the flow definition.
1944 1945 1946 1947 1948 1949 1950 |
# File 'lib/aws-sdk-textract/types.rb', line 1944 class HumanLoopConfig < Struct.new( :human_loop_name, :flow_definition_arn, :data_attributes) SENSITIVE = [] include Aws::Structure end |
#human_loop_name ⇒ String
The name of the human workflow used for this image. This should be kept unique within a region.
1944 1945 1946 1947 1948 1949 1950 |
# File 'lib/aws-sdk-textract/types.rb', line 1944 class HumanLoopConfig < Struct.new( :human_loop_name, :flow_definition_arn, :data_attributes) SENSITIVE = [] include Aws::Structure end |