Class: Aws::Textract::Types::HumanLoopConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::HumanLoopConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Note:
When making an API call, you may pass HumanLoopConfig data as a hash:
{
human_loop_name: "HumanLoopName", # required
flow_definition_arn: "FlowDefinitionArn", # required
data_attributes: {
content_classifiers: ["FreeOfPersonallyIdentifiableInformation"], # accepts FreeOfPersonallyIdentifiableInformation, FreeOfAdultContent
},
}
Sets up the human review workflow the document will be sent to if one of the conditions is met. You can also set certain attributes of the image before review.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_attributes ⇒ Types::HumanLoopDataAttributes
Sets attributes of the input data.
-
#flow_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the flow definition.
-
#human_loop_name ⇒ String
The name of the human workflow used for this image.
Instance Attribute Details
#data_attributes ⇒ Types::HumanLoopDataAttributes
Sets attributes of the input data.
1116 1117 1118 1119 1120 1121 1122 |
# File 'lib/aws-sdk-textract/types.rb', line 1116 class HumanLoopConfig < Struct.new( :human_loop_name, :flow_definition_arn, :data_attributes) SENSITIVE = [] include Aws::Structure end |
#flow_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the flow definition.
1116 1117 1118 1119 1120 1121 1122 |
# File 'lib/aws-sdk-textract/types.rb', line 1116 class HumanLoopConfig < Struct.new( :human_loop_name, :flow_definition_arn, :data_attributes) SENSITIVE = [] include Aws::Structure end |
#human_loop_name ⇒ String
The name of the human workflow used for this image. This should be kept unique within a region.
1116 1117 1118 1119 1120 1121 1122 |
# File 'lib/aws-sdk-textract/types.rb', line 1116 class HumanLoopConfig < Struct.new( :human_loop_name, :flow_definition_arn, :data_attributes) SENSITIVE = [] include Aws::Structure end |