Class: Aws::Textract::Types::S3Object
- Inherits:
-
Struct
- Object
- Struct
- Aws::Textract::Types::S3Object
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-textract/types.rb
Overview
Note:
When making an API call, you may pass S3Object data as a hash:
{
bucket: "S3Bucket",
name: "S3ObjectName",
version: "S3ObjectVersion",
}
The S3 bucket name and file name that identifies the document.
The AWS Region for the S3 bucket that contains the document must match the Region that you use for Amazon Textract operations.
For Amazon Textract to process a file in an S3 bucket, the user must have permission to access the S3 bucket and file.
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the S3 bucket.
-
#name ⇒ String
The file name of the input document.
-
#version ⇒ String
If the bucket has versioning enabled, you can specify the object version.
Instance Attribute Details
#bucket ⇒ String
The name of the S3 bucket.
721 722 723 724 725 726 |
# File 'lib/aws-sdk-textract/types.rb', line 721 class S3Object < Struct.new( :bucket, :name, :version) include Aws::Structure end |
#name ⇒ String
The file name of the input document. It must be an image file (.JPG or .PNG format). Asynchronous operations also support PDF files.
721 722 723 724 725 726 |
# File 'lib/aws-sdk-textract/types.rb', line 721 class S3Object < Struct.new( :bucket, :name, :version) include Aws::Structure end |
#version ⇒ String
If the bucket has versioning enabled, you can specify the object version.
721 722 723 724 725 726 |
# File 'lib/aws-sdk-textract/types.rb', line 721 class S3Object < Struct.new( :bucket, :name, :version) include Aws::Structure end |